Module gain_chart

Module gain_chart 

Cumulative gain and lift charts for ranking/classification evaluation.

Structs

GainChart
A cumulative gain or lift chart as a drawable series (coordinate space (f64, f64)).

Enums

GainMode
Whether a GainChart shows the cumulative gain curve or the lift curve.