Module gain

Module gain 

Cumulative gain and lift curves for ranking/classification evaluation.

Structs

GainPoint
One point on a cumulative gain / lift curve.

Functions

gain_curve
Compute the cumulative gain / lift curve from predicted scores and true binary labels. Points are ordered by descending score and always start at fraction == 0, gain == 0.