pub struct GainChart { /* private fields */ }Expand description
A cumulative gain or lift chart as a drawable series (coordinate space
(f64, f64)).
Implementations
Sourceimpl GainChart
impl GainChart
Sourcepub fn from_scores(scores: &[f64], labels: &[bool]) -> Result<Self, StatsError>
pub fn from_scores(scores: &[f64], labels: &[bool]) -> Result<Self, StatsError>
Build from predicted scores and true binary labels, defaulting to the
cumulative-gain view.
Sourcepub fn stroke_width(self, width: u32) -> Self
pub fn stroke_width(self, width: u32) -> Self
Set the line stroke width in pixels.