Module gain_chart
plotters_
statistical
0.1.0
Module gain_
chart
Module Items
Structs
Enums
In plotters_
statistical::
series
plotters_statistical
::
series
Module
gain_
chart
Cumulative gain and lift charts for ranking/classification evaluation.
Structs

Gain
Chart
A cumulative gain or lift chart as a drawable series (coordinate space
(f64, f64)
).
Enums

Gain
Mode
Whether a
GainChart
shows the cumulative gain curve or the lift curve.