Gaussian kernel density estimation, used to shape violin plots.
Structs
- KdeCurve
- An evaluated kernel density estimate: paired
xpositions and density values, plus the bandwidth that produced them.
Functions
- kde_
curve - Evaluate a Gaussian KDE of
dataon a uniform grid. - silverman_
bandwidth - Silverman’s rule-of-thumb bandwidth:
h = 0.9 * min(std, IQR/1.34) * n^(-1/5).